@@ -91,15 +91,19 @@ importSummarisedResultFromPath <- function(path,
   allResults[["empty"]] <- emptySummarisedResult()
   for (i in seq_along(csvFiles)) {
     cli::cli_inform("Reading {csvFiles[[i]]}")
-    allResults[[i]] <- readr::read_csv(csvFiles[[i]],
-      col_types = c(
-        .default = "c",
-        result_id = "integer"
-      ),
+    enc <- readr::guess_encoding(csvFiles[[i]], n_max = -1)
+    if (is.character(enc$encoding[1])) {
+      locale <- readr::locale(encoding = enc$encoding[1])
+    } else {
+      locale <- readr::default_locale()
+    }
+    allResults[[i]] <- readr::read_csv(
+      file = csvFiles[[i]],
+      col_types = c(.default = "c", result_id = "i"),
+      locale = locale,
       show_col_types = FALSE
     )
 
-
     if (isFALSE(setequal(sort(colnames(allResults[[i]])), sort(resultColumns())))) {
       cli::cli_warn("{csvFileNames[[i]]} does not have summarised result columns and so was omitted")
       allResults[[i]] <- emptySummarisedResult()
